aboutsummaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorこけっち <50144466+sim1222@users.noreply.github.com>2024-09-03 23:11:26 +0900
committerGitHub <noreply@github.com>2024-09-03 14:11:26 +0000
commitfdd3a9cdf7167ca8fc84ec9a7e583f6410a27188 (patch)
tree777feea72ae708f33b5740aac7b327d858f39ce0
parentd1d7d5468091fc71fb85c090da87253efdfcdf08 (diff)
downloadrneovim-fdd3a9cdf7167ca8fc84ec9a7e583f6410a27188.tar.gz
rneovim-fdd3a9cdf7167ca8fc84ec9a7e583f6410a27188.tar.bz2
rneovim-fdd3a9cdf7167ca8fc84ec9a7e583f6410a27188.zip
docs: use "nvim" in swapfile message #30250
Problem: The message E325 displays “vim -r” to recover the file. Solution: Change the message to display “nvim -r” instead of “vim -r”.
-rw-r--r--src/nvim/memline.c4
-rw-r--r--src/nvim/po/af.po4
-rw-r--r--src/nvim/po/ca.po4
-rw-r--r--src/nvim/po/cs.cp1250.po4
-rw-r--r--src/nvim/po/cs.po4
-rw-r--r--src/nvim/po/da.po4
-rw-r--r--src/nvim/po/de.po4
-rw-r--r--src/nvim/po/en_GB.po2
-rw-r--r--src/nvim/po/eo.po4
-rw-r--r--src/nvim/po/es.po4
-rw-r--r--src/nvim/po/fi.po4
-rw-r--r--src/nvim/po/fr.po4
-rw-r--r--src/nvim/po/ga.po4
-rw-r--r--src/nvim/po/it.po4
-rw-r--r--src/nvim/po/ja.euc-jp.po4
-rw-r--r--src/nvim/po/ja.po4
-rw-r--r--src/nvim/po/ko.UTF-8.po4
-rw-r--r--src/nvim/po/nb.po4
-rw-r--r--src/nvim/po/nl.po4
-rw-r--r--src/nvim/po/no.po4
-rw-r--r--src/nvim/po/pl.UTF-8.po4
-rw-r--r--src/nvim/po/pt_BR.po4
-rw-r--r--src/nvim/po/ru.po4
-rw-r--r--src/nvim/po/sk.cp1250.po4
-rw-r--r--src/nvim/po/sk.po4
-rw-r--r--src/nvim/po/sr.po4
-rw-r--r--src/nvim/po/sv.po4
-rw-r--r--src/nvim/po/tr.po4
-rw-r--r--src/nvim/po/uk.po4
-rw-r--r--src/nvim/po/vi.po4
-rw-r--r--src/nvim/po/zh_CN.UTF-8.po4
-rw-r--r--src/nvim/po/zh_TW.UTF-8.po4
32 files changed, 63 insertions, 63 deletions
diff --git a/src/nvim/po/af.po b/src/nvim/po/af.po
index 751d8b8d05..64acd93f57 100644
--- a/src/nvim/po/af.po
+++ b/src/nvim/po/af.po
@@ -3608,8 +3608,8 @@ msgstr ""
#~ "\n"
#~ "(2) 'n Bewerkingsessie van hierdie ler het ineengestort.\n"
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Indien wel, gebruik \":recover\" of \"vim -r"
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Indien wel, gebruik \":recover\" of \"nvim -r"
msgid ""
"\"\n"
diff --git a/src/nvim/po/ca.po b/src/nvim/po/ca.po
index 946d2c5041..44975d9161 100644
--- a/src/nvim/po/ca.po
+++ b/src/nvim/po/ca.po
@@ -4015,8 +4015,8 @@ msgstr ""
"(2) El Vim s'ha estrellat mentre s'editava aquest fitxer.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " En aquest cas, useu \":recover\" o b \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " En aquest cas, useu \":recover\" o b \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/cs.cp1250.po b/src/nvim/po/cs.cp1250.po
index 2ed8904319..43b6c82960 100644
--- a/src/nvim/po/cs.cp1250.po
+++ b/src/nvim/po/cs.cp1250.po
@@ -4077,8 +4077,8 @@ msgstr ""
"(2) Editace tohoto souboru byla peruena neekanm ukonenm programu.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Je-li tomu tak, pak pouijte \":recover\" i \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Je-li tomu tak, pak pouijte \":recover\" i \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/cs.po b/src/nvim/po/cs.po
index 77696a7650..7df69e061f 100644
--- a/src/nvim/po/cs.po
+++ b/src/nvim/po/cs.po
@@ -4077,8 +4077,8 @@ msgstr ""
"(2) Editace tohoto souboru byla peruena neekanm ukonenm programu.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Je-li tomu tak, pak pouijte \":recover\" i \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Je-li tomu tak, pak pouijte \":recover\" i \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/da.po b/src/nvim/po/da.po
index 1ddabd7768..ed9e357092 100644
--- a/src/nvim/po/da.po
+++ b/src/nvim/po/da.po
@@ -3663,8 +3663,8 @@ msgstr ""
msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) En redigeringssession for filen holdt op med at virke.\n"
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Hvis det er tilfældet, så brug \":recover\" eller \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Hvis det er tilfældet, så brug \":recover\" eller \"nvim -r "
msgid ""
"\"\n"
diff --git a/src/nvim/po/de.po b/src/nvim/po/de.po
index 5974982361..0d1195eecf 100644
--- a/src/nvim/po/de.po
+++ b/src/nvim/po/de.po
@@ -3436,9 +3436,9 @@ msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) Eine Sitzung fr diese Datei ist abgestrzt.\n"
#: ../memline.c:3204
-msgid " If this is the case, use \":recover\" or \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
msgstr ""
-" Wenn dies der Fall ist, so verwenden Sie \":recover\" oder \"vim -r "
+" Wenn dies der Fall ist, so verwenden Sie \":recover\" oder \"nvim -r "
#: ../memline.c:3206
msgid ""
diff --git a/src/nvim/po/en_GB.po b/src/nvim/po/en_GB.po
index c8307d47ce..7b849d4e68 100644
--- a/src/nvim/po/en_GB.po
+++ b/src/nvim/po/en_GB.po
@@ -3847,7 +3847,7 @@ msgid "(2) An edit session for this file crashed.\n"
msgstr ""
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
msgstr ""
#: ../memline.c:3249
diff --git a/src/nvim/po/eo.po b/src/nvim/po/eo.po
index 120b883a87..5cd18ad24b 100644
--- a/src/nvim/po/eo.po
+++ b/src/nvim/po/eo.po
@@ -3531,8 +3531,8 @@ msgstr ""
msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) Redakta seanco de tiu dosiero kolapsis.\n"
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Se veras, uzu \":recover\" aŭ \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Se veras, uzu \":recover\" aŭ \"nvim -r "
msgid ""
"\"\n"
diff --git a/src/nvim/po/es.po b/src/nvim/po/es.po
index e64b9261c5..292ca15264 100644
--- a/src/nvim/po/es.po
+++ b/src/nvim/po/es.po
@@ -4078,8 +4078,8 @@ msgstr ""
"(2) Falló una sesión de edición de este archivo.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Si es así, use \":recover\" o \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Si es así, use \":recover\" o \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/fi.po b/src/nvim/po/fi.po
index 5557c3ccc3..c9cad6cc69 100644
--- a/src/nvim/po/fi.po
+++ b/src/nvim/po/fi.po
@@ -3660,8 +3660,8 @@ msgstr ""
msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) Tiedostonmuokkausistunto on kaatunut.\n"
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Jos näin on, käytä komentoa :recover tai vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Jos näin on, käytä komentoa :recover tai nvim -r "
msgid ""
"\"\n"
diff --git a/src/nvim/po/fr.po b/src/nvim/po/fr.po
index d9058326d5..b561347ab8 100644
--- a/src/nvim/po/fr.po
+++ b/src/nvim/po/fr.po
@@ -3241,8 +3241,8 @@ msgstr ""
msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) Une session d'dition de ce fichier a plant.\n"
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Si c'est le cas, utilisez \":recover\" ou \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Si c'est le cas, utilisez \":recover\" ou \"nvim -r "
msgid ""
"\"\n"
diff --git a/src/nvim/po/ga.po b/src/nvim/po/ga.po
index 4fdf110538..7a5893b5f2 100644
--- a/src/nvim/po/ga.po
+++ b/src/nvim/po/ga.po
@@ -3696,8 +3696,8 @@ msgstr ""
msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) Thuairteil seisin eagarthireachta.\n"
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Ms amhlaidh, bain sid as \":recover\" n \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Ms amhlaidh, bain sid as \":recover\" n \"nvim -r "
msgid ""
"\"\n"
diff --git a/src/nvim/po/it.po b/src/nvim/po/it.po
index 64c04a32ee..d02052ec39 100644
--- a/src/nvim/po/it.po
+++ b/src/nvim/po/it.po
@@ -4037,8 +4037,8 @@ msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) Una sessione di edit per questo file finita male.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Se cos, usa \":recover\" oppure \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Se cos, usa \":recover\" oppure \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/ja.euc-jp.po b/src/nvim/po/ja.euc-jp.po
index bcd55b280c..78f927c21d 100644
--- a/src/nvim/po/ja.euc-jp.po
+++ b/src/nvim/po/ja.euc-jp.po
@@ -3466,8 +3466,8 @@ msgstr ""
msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) ΥեԽå󤬥å夷.\n"
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " ξˤ \":recover\" \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " ξˤ \":recover\" \"nvim -r "
msgid ""
"\"\n"
diff --git a/src/nvim/po/ja.po b/src/nvim/po/ja.po
index 2cd4cb1a7a..1a493c0336 100644
--- a/src/nvim/po/ja.po
+++ b/src/nvim/po/ja.po
@@ -5092,8 +5092,8 @@ msgstr ""
msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) このファイルの編集セッションがクラッシュした.\n"
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " この場合には \":recover\" か \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " この場合には \":recover\" か \"nvim -r "
msgid ""
"\"\n"
diff --git a/src/nvim/po/ko.UTF-8.po b/src/nvim/po/ko.UTF-8.po
index 51f8771052..03dff518f3 100644
--- a/src/nvim/po/ko.UTF-8.po
+++ b/src/nvim/po/ko.UTF-8.po
@@ -3957,8 +3957,8 @@ msgstr ""
"(2) 파일을 고치다가 죽었었습니다.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " 만약 그렇다면 \":recover\" 혹은 \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " 만약 그렇다면 \":recover\" 혹은 \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/nb.po b/src/nvim/po/nb.po
index 2e28964aeb..d512789246 100644
--- a/src/nvim/po/nb.po
+++ b/src/nvim/po/nb.po
@@ -3978,8 +3978,8 @@ msgstr ""
"(2) En kt for denne filen krsjet.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Hvis det er tilfelle, bruk \":recover\" eller \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Hvis det er tilfelle, bruk \":recover\" eller \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/nl.po b/src/nvim/po/nl.po
index d4c240af55..f6ce5ddc9f 100644
--- a/src/nvim/po/nl.po
+++ b/src/nvim/po/nl.po
@@ -3984,8 +3984,8 @@ msgstr ""
"(2) Een sessie waarin dit bestand werd bewerkt is onverhoeds gestopt.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Als dit het geval is, gebruikt dan \":recover\" of \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Als dit het geval is, gebruikt dan \":recover\" of \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/no.po b/src/nvim/po/no.po
index 2e28964aeb..d512789246 100644
--- a/src/nvim/po/no.po
+++ b/src/nvim/po/no.po
@@ -3978,8 +3978,8 @@ msgstr ""
"(2) En kt for denne filen krsjet.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Hvis det er tilfelle, bruk \":recover\" eller \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Hvis det er tilfelle, bruk \":recover\" eller \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/pl.UTF-8.po b/src/nvim/po/pl.UTF-8.po
index 729e3b0984..b7200a7ba8 100644
--- a/src/nvim/po/pl.UTF-8.po
+++ b/src/nvim/po/pl.UTF-8.po
@@ -3946,8 +3946,8 @@ msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) Sesja edycji dla pliku załamała się.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Jeśli tak, to użyj \":recover\" lub \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Jeśli tak, to użyj \":recover\" lub \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/pt_BR.po b/src/nvim/po/pt_BR.po
index a02db16a3e..3f2f87991c 100644
--- a/src/nvim/po/pt_BR.po
+++ b/src/nvim/po/pt_BR.po
@@ -625,8 +625,8 @@ msgstr ""
"(2) Ocorreu um travamento numa sesso de edio desse arquivo.\n"
#: ../memline.c:3206
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Se esse for o caso, use \":recover\" ou \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Se esse for o caso, use \":recover\" ou \"nvim -r "
#: ../memline.c:3208
msgid ""
diff --git a/src/nvim/po/ru.po b/src/nvim/po/ru.po
index c6227d896e..64c18f890c 100644
--- a/src/nvim/po/ru.po
+++ b/src/nvim/po/ru.po
@@ -3985,8 +3985,8 @@ msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) Сеанс редактирования этого файла завершён аварийно.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " В этом случае, используйте команду \":recover\" или \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " В этом случае, используйте команду \":recover\" или \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/sk.cp1250.po b/src/nvim/po/sk.cp1250.po
index 1cc47564d3..9510a357f0 100644
--- a/src/nvim/po/sk.cp1250.po
+++ b/src/nvim/po/sk.cp1250.po
@@ -3975,8 +3975,8 @@ msgstr ""
"(2) prava tohoto sboru bola preruen neoakvanm ukonenm programu.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Ak je tomu tak, potom pouite \":recover\" alebo \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Ak je tomu tak, potom pouite \":recover\" alebo \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/sk.po b/src/nvim/po/sk.po
index 564bb2ea3c..21791e0061 100644
--- a/src/nvim/po/sk.po
+++ b/src/nvim/po/sk.po
@@ -3975,8 +3975,8 @@ msgstr ""
"(2) prava tohoto sboru bola preruen neoakvanm ukonenm programu.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Ak je tomu tak, potom pouite \":recover\" alebo \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Ak je tomu tak, potom pouite \":recover\" alebo \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/sr.po b/src/nvim/po/sr.po
index c0866b2ccf..1cbb37eeb1 100644
--- a/src/nvim/po/sr.po
+++ b/src/nvim/po/sr.po
@@ -4048,8 +4048,8 @@ msgstr ""
msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) Сесија уређивања ове датотеке се срушила.\n"
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Ако је ово случај, користите \":recover\" или \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Ако је ово случај, користите \":recover\" или \"nvim -r "
msgid ""
"\"\n"
diff --git a/src/nvim/po/sv.po b/src/nvim/po/sv.po
index 93c81f72a3..89a7717746 100644
--- a/src/nvim/po/sv.po
+++ b/src/nvim/po/sv.po
@@ -6171,8 +6171,8 @@ msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) En redigeringssession fr den hr filen kraschade.\n"
#: ../memline.c:3200
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Om s r fallet, anvnd \":recover\" eller \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Om s r fallet, anvnd \":recover\" eller \"nvim -r "
#: ../memline.c:3202
msgid ""
diff --git a/src/nvim/po/tr.po b/src/nvim/po/tr.po
index 91a50a299b..a4c7926c67 100644
--- a/src/nvim/po/tr.po
+++ b/src/nvim/po/tr.po
@@ -3947,8 +3947,8 @@ msgstr ""
msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) Bu dosya düzenleme oturumu çöktü.\n"
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Durum buysa \":recover\" veya \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Durum buysa \":recover\" veya \"nvim -r "
msgid ""
"\"\n"
diff --git a/src/nvim/po/uk.po b/src/nvim/po/uk.po
index 4ef767abc2..ff6fe9a33e 100644
--- a/src/nvim/po/uk.po
+++ b/src/nvim/po/uk.po
@@ -5108,8 +5108,8 @@ msgstr ""
msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) Сеанс редагування цього файлу зазнав краху.\n"
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " Якщо це справді трапилося, спробуйте «:recover» або «vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " Якщо це справді трапилося, спробуйте «:recover» або «nvim -r "
msgid ""
"\"\n"
diff --git a/src/nvim/po/vi.po b/src/nvim/po/vi.po
index c0d21d7c72..3e88ac446c 100644
--- a/src/nvim/po/vi.po
+++ b/src/nvim/po/vi.po
@@ -4009,9 +4009,9 @@ msgstr ""
"(2) Lần soạn thảo trước của tập tin này gặp sự cố.\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
msgstr ""
-" Trong trường hợp này, hãy sử dụng câu lệnh \":recover\" hoặc \"vim -r "
+" Trong trường hợp này, hãy sử dụng câu lệnh \":recover\" hoặc \"nvim -r "
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/po/zh_CN.UTF-8.po b/src/nvim/po/zh_CN.UTF-8.po
index a34697a1bf..e30fc47806 100644
--- a/src/nvim/po/zh_CN.UTF-8.po
+++ b/src/nvim/po/zh_CN.UTF-8.po
@@ -4780,8 +4780,8 @@ msgid "(2) An edit session for this file crashed.\n"
msgstr "(2) 上次编辑此文件时崩溃。\n"
#: ../memline.c:3099
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " 如果是这样,请用 \":recover\" 或 \"vim -r "
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " 如果是这样,请用 \":recover\" 或 \"nvim -r "
#: ../memline.c:3101
msgid ""
diff --git a/src/nvim/po/zh_TW.UTF-8.po b/src/nvim/po/zh_TW.UTF-8.po
index dbb5a12bea..cbbc4ad6eb 100644
--- a/src/nvim/po/zh_TW.UTF-8.po
+++ b/src/nvim/po/zh_TW.UTF-8.po
@@ -4017,8 +4017,8 @@ msgstr ""
"(2) 前次編輯此檔時當機\n"
#: ../memline.c:3247
-msgid " If this is the case, use \":recover\" or \"vim -r "
-msgstr " 如果是這樣, 請用 \":recover\" 或 \"vim -r"
+msgid " If this is the case, use \":recover\" or \"nvim -r "
+msgstr " 如果是這樣, 請用 \":recover\" 或 \"nvim -r"
#: ../memline.c:3249
msgid ""
diff --git a/src/nvim/memline.c b/src/nvim/memline.c
index eac62aeda2..a8f0035b84 100644
--- a/src/nvim/memline.c
+++ b/src/nvim/memline.c
@@ -1250,7 +1250,7 @@ theend:
/// with the 'directory' option.
///
/// Used to:
/// - list the swapfiles for "vim -r"
/// - count the number of swapfiles when recovering
/// - list the swapfiles when recovering
/// - list the swapfiles for swapfilelist()
@@ -3280,7 +3280,7 @@ static void attention_message(buf_T *buf, char *fname)
" instances of the same\n file when making changes."
" Quit, or continue with caution.\n"));
msg_puts(_("(2) An edit session for this file crashed.\n"));
- msg_puts(_(" If this is the case, use \":recover\" or \"vim -r "));
+ msg_puts(_(" If this is the case, use \":recover\" or \"nvim -r "));
msg_outtrans(buf->b_fname, 0);
msg_puts(_("\"\n to recover the changes (see \":help recovery\").\n"));
msg_puts(_(" If you did this already, delete the swap file \""));
@@ -1250,7 +1250,7 @@ theend:
///
/// Used to:
-/// - list the swapfiles for "vim -r"
+/// - list the swapfiles for "nvim -r"
/// - count the number of swapfiles when recovering
/// - list the swapfiles when recovering